@@ -5,20 +5,31 @@ __author__ = "Brendan Kristiansen"
 __copyright__ = "Copyright 2021, Brendan Kristiansen"
 __credits__ = ["Brendan Kristiansen"]
 __license__ = "MPL 2.0"
-__version__ = "0.1.0"
 __maintainer__ = "Brendan Kristiansen"
 __email__ = "b@bek.sh"
 
 
 class SVObservation:
+    """ Contains a snapshot of the receiver's connection to a satellite at a point in time
+    """
 
+    _gpst: str
     _prn: int
     _elev: float
     _az: float
     _snr: float
 
-    def __init__(self, prn: int, elev: float, azimuth: float, snr: float):
+    def __init__(self, gpst: str, prn: int, elev: float, azimuth: float, snr: float):
+        """ Constructor
 
+        :param gpst: GPS Timestamp
+        :param prn: Satellite number
+        :param elev: Elevation angle in sky
+        :param azimuth: Azimuth of satellite
+        :param snr: Signal to noise ratio
+        """
+
+        self._gpst = gpst
         self._prn = prn
         self._elev = elev
         self._az = azimuth
@@ -27,22 +38,9 @@ class SVObservation:
     def __str__(self):
         return "Observation of SV %d: SNR %f" % (self._prn, self._snr)
 
-    def generate_insert_statement(self, gpst) -> str:
-        """ Generate an SQL insert statement to record this observation
-
-        :return: Statement for database
-
-        """
-
-        stmt = "INSERT INTO sv_observation ("
-        stmt += '"%s", ' % gpst
-        stmt += str(self._prn) + ', '
-        stmt += str(self._elev) + ', '
-        stmt += str(self._az) + ', '
-        stmt += str(self._snr) + ', '
-        stmt += ');'
-
-        return stmt
+    @property
+    def gpst(self):
+        return self._gpst
 
     @property
     def prn(self):
